@@ -11,18 +11,10 @@ def func(x: list[int]) -> None:
     x += [9]
 
 
-@pytest.mark.test_idempotency
+@pytest.mark.idempotent
 def test_func() -> None:
     x: list[int] = []
 
     func(x)
 
     assert x == [9]
-
-
-def test_func_without_idempotency_check() -> None:
-    x: list[int] = []
-
-    func(x)
-
-    assert x == [9]
